Обзор возможностей СпамоБорца — СпамоБорец: документация

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »
- Руководство пользователя »

# Обзор возможностей СпамоБорца

СпамоБорец предоставляет API, с помощью которого клиенты, используя протокол HTTP и любой из протоколов XML-RPC/JSON-RPC, могут отправлять запросы к серверу.

На рисунке изображена схема обслуживания основной команды API, sf.message.input, которая отправляет сообщение на обработку в сервер СпамоБорца. По запросу API определяется партнер, от имени которого выполняется команда (авторизация), а с помощью партнера - и домен, относительно которого происходит обработка запроса.

Сообщение относительно домена проходит десериализацию с помощью домена сообщений. В домене находится firewall, который определяет порядок обработки сообщений, набор правил, которые будут применены к сообщению. Правила в процессе своей работы могут обращаться к моделям анализа сообщений, хранилищам данных, а также другим компонентам СпамоБорца. В конце обработки сообщение помещается в лог сообщений для контроля работы набора правил. Результат анализа отправляется через API обратно к клиенту.

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »
- Руководство пользователя »